Direct contributions:

- `José Vinícius de Miranda Cardoso <https://github.com/mirca>`_
- `Geert Barentsen <https://github.com/barentsen>`_
- `Ann Marie Cody <https://github.com/amcody>`_
- `Christina Hedges <https://github.com/christinahedges>`_
- `Michael Gully-Santiago <https://github.com/gully>`_
- `Thomas Barclay <https://github.com/mrtommyb>`_
- `Ken Mighell <https://github.com/KenMighell>`_
- `Keaton Bell <https://github.com/keatonb>`_
- `Johnny Zhang <https://github.com/johnnyzhang295>`_
- `Andy Tzanidakis <https://github.com/AndyTza>`_
- `Sheila Sagear <https://github.com/ssagear>`_
- `Emma Turtelboom <https://github.com/Emmavt>`_
- `Jeff Coughlin <https://github.com/JeffLCoughlin>`_
- `Zachory K. Berta-Thompson <https://github.com/zkbt>`_
- `Anand Sundaram <https://github.com/anand-sundaram-zocdoc>`_
- `Oliver Hall <https://github.com/ojhall94>`_
- `Nicholas Saunders <https://github.com/nksaunders>`_
- `Jose A. Lerma III <https://github.com/JoseALermaIII>`_
- `Dag Evensberget <https://github.com/svaberg>`_
- `Natalie Gosnell <https://github.com/nattieg>`_
- `Peter Williams <https://github.com/pkgw>`_
- `Richard Elkins <https://github.com/texadactyl>`_


Comments, corrections & suggestions:

- `Clare Brasseur <https://github.com/ceb8>`_
- `Doug Caldwell <https://github.com/dacmess>`_
- `Jessie Dotson <https://github.com/jessie-dotson>`_
- `Scott Fleming <https://github.com/scfleming>`_
- `Daniel Foreman-Mackey <https://github.com/dfm>`_
- TJ Jaffe
- `Susan Mullally <https://github.com/mustaric>`_
- `Elisa Quintana <https://github.com/elisaquintana>`_
- Jeff Van Cleve
- Ashley Villar
- `Benjamin Pope <https://github.com/benjaminpope>`_
- `J. K. Carlberg <https://github.com/jkcarlberg>`_
- `Brian Jackson <https://github.com/decaelus>`_
- `Rishi Paudel <https://github.com/rrpastro>`_
- `Marusa Zerjal <https://github.com/marusazerjal>`_
- `Michael Hippke <https://github.com/hippke>`_
- `Molnár László <https://github.com/lacalaca85>`_
- `Tom Wilson <https://github.com/Onoddil>`_
